==> pdf-model-arlington-1.25.14-sources.jar: org/verapdf/model/alayer/ASeparationColorSpace.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ASeparationColorSpace extends AObject {
	



	/**
	*/
	public Boolean getentry0HasTypeName();

	/**
	*/
	public String getentry0NameValue();

	/**
	*/
	public Boolean getentry1HasTypeName();

	/**
	*/
	public Boolean getentry2HasTypeArray();

	/**
	*/
	public Boolean getentry2HasTypeName();

	/**
	*/
	public String getentry2NameValue();

	/**
	*/
	public Boolean getisentry3Indirect();

	/**
	*/
	public Boolean getentry3HasTypeDictionary();

	/**
	*/
	public Boolean getentry3HasTypeStream();
}

==> pdf-model-arlington-1.25.42-sources.jar: org/verapdf/model/alayer/ASeparationColorSpace.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ASeparationColorSpace extends AObject {
	



	/**
	*/
	public String getentry0Type();

	/**
	*/
	public Boolean getentry0HasTypeName();

	/**
	*/
	public String getentry0NameValue();

	/**
	*/
	public String getentry1Type();

	/**
	*/
	public Boolean getentry1HasTypeName();

	/**
	*/
	public String getentry2Type();

	/**
	*/
	public Boolean getentry2HasTypeArray();

	/**
	*/
	public Boolean getentry2HasTypeName();

	/**
	*/
	public String getentry2NameValue();

	/**
	*/
	public Boolean getisentry3Indirect();

	/**
	*/
	public String getentry3Type();

	/**
	*/
	public Boolean getentry3HasTypeDictionary();

	/**
	*/
	public Boolean getentry3HasTypeStream();
}
